==> tubectrl-0.1.1-py3-none-any.whl: tubectrl/models/video.py <==
from pydantic import BaseModel, Field
from .snippet import Snippet
from .status import Status
from .statistics import Statistics
from .paid_product_placement_details import PaidProductPlacementDetails
from .player import Player
from .topic_details import TopicDetails
from .recording_details import RecordingDetails
from .file_details import FileDetails
from .processing_details import ProcessingDetails
from .suggestions import Suggestions
from .livestreaming_details import LiveStreamingDetails
from .localizations import Localizations
from typing import Optional


class Video(BaseModel):
    kind: Optional[str] = Field(default=None)
    etag: Optional[str] = Field(default=None)
    id: Optional[str] = Field(default=None)
    snippet: Optional[Snippet] = Field(default=None)
    status: Optional[Status] = Field(default=None)
    statistics: Optional[Statistics] = Field(default=None)
    paidProductPlacementDetails: Optional[PaidProductPlacementDetails] = Field(
        default=None
    )
    player: Optional[Player] = Field(default=None)
    topicDetails: Optional[TopicDetails] = Field(default=None)
    recordingDetails: Optional[RecordingDetails] = Field(default=None)
    fileDetails: Optional[FileDetails] = Field(default=None)
    processingDetails: Optional[ProcessingDetails] = Field(default=None)
    suggestions: Optional[Suggestions] = Field(default=None)
    liveStreamingDetails: Optional[LiveStreamingDetails] = Field(default=None)
    localizations: Optional[Localizations] = Field(default=None)

==> tubectrl-0.4.0-py3-none-any.whl: tubectrl/models/video.py <==
from typing import Optional

from pydantic import BaseModel, Field

from .file_details import FileDetails
from .livestreaming_details import LiveStreamingDetails
from .localizations import Localizations
from .paid_product_placement_details import PaidProductPlacementDetails
from .player import Player
from .processing_details import ProcessingDetails
from .recording_details import RecordingDetails
from .statistics import Statistics
from .suggestions import Suggestions
from .topic_details import TopicDetails
from .video_snippet import VideoSnippet
from .video_status import VideoStatus


class Video(BaseModel):
    kind: Optional[str] = Field(default=None)
    etag: Optional[str] = Field(default=None)
    id: Optional[str] = Field(default=None)
    snippet: Optional[VideoSnippet] = Field(default=None)
    status: Optional[VideoStatus] = Field(default=None)
    statistics: Optional[Statistics] = Field(default=None)
    paidProductPlacementDetails: Optional[PaidProductPlacementDetails] = Field(
        default=None
    )
    player: Optional[Player] = Field(default=None)
    topicDetails: Optional[TopicDetails] = Field(default=None)
    recordingDetails: Optional[RecordingDetails] = Field(default=None)
    fileDetails: Optional[FileDetails] = Field(default=None)
    processingDetails: Optional[ProcessingDetails] = Field(default=None)
    suggestions: Optional[Suggestions] = Field(default=None)
    liveStreamingDetails: Optional[LiveStreamingDetails] = Field(default=None)
    localizations: Optional[Localizations] = Field(default=None)
